@@ -30,7 +30,7 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QFormLayout>
-#include <KLocale>
+#include <klocalizedstring.h>
 
 Dictionary::Dictionary(QWidget *p) : QWidget(p)
 {
@@ -107,10 +107,6 @@ void Dictionary::activated(const QModelIndex& idx, const QModelIndex& prev)
 		m_sample->setText(sample);
 		m_example->setText(example);
 
-		QString error;
-		if(!error.isEmpty())
-			qDebug() << "dict formula error: " << error << e.toMathMLPresentation();
-
 		m_funcs->addPlot(Analitza::PlotsFactory::self()->requestPlot(e, Analitza::Dim2D, m_vars).create(QColor(0,150,0), "dict"));
 	} else {
 		QString error;
